﻿#region Using directives

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.Text;
using System.Windows.Forms;

#endregion

namespace BrushesSample {
  partial class HatchBrushesForm : Form {
    public HatchBrushesForm() {
      InitializeComponent();
    }

      enum WM: int
      {
          NOTIFYPARENT = 0x210,
          LBUTTONDOWN = 0x201,
          RBUTTONDOWN = 0x204
      }

      private const int WM_NOTIFYPARENT = 0x210;

      public static int LoWord(int dwValue)
      {
          return dwValue & 0xFFFF;
      }
      public static int HiWord(int dwValue)
      {
          return (dwValue >> 16) & 0xFFFF;
      }

      protected override void WndProc(ref Message m)
      {
          if (m.Msg == (int)WM.NOTIFYPARENT)
          {
              Console.Out.WriteLine("Message: {0}", m);
              switch (m.WParam.ToInt32())
              {
                  case (int)WM.LBUTTONDOWN:
                      Console.Out.WriteLine("LBUTTONDOWN: {0:X4}", m.WParam.ToInt32());
                      Console.Out.WriteLine("{0}X={1}, Y={2}{3}", "{",
                          LoWord(m.LParam.ToInt32()),
                          HiWord(m.LParam.ToInt32()), "}");
                      break;
                  case (int) WM.RBUTTONDOWN:
                      Console.Out.WriteLine("RBUTTONDOWN: {0:X4}", m.WParam.ToInt32());
                      Console.Out.WriteLine("(X={0},Y={1})", 
                          LoWord(m.LParam.ToInt32()),
                          HiWord(m.LParam.ToInt32()));              
                      break;
              }
          }
          base.WndProc(ref m);
      }

      private void HatchBrushesForm_Paint(object sender, PaintEventArgs e)
      {
          
      }

      private void foregroundToolStripMenuItem_Click(object sender, EventArgs e)
      {
          using (ColorDialog dlg = new ColorDialog())
          {
              dlg.Color = this.colorFore;
              if (dlg.ShowDialog() == DialogResult.OK)
              {
                  this.colorFore = dlg.Color;
                  panelDraw.Invalidate();
              }
          }
      }

      private Color colorFore = Color.Black;
      private Color colorBack = Color.White;

      private void backgroundToolStripMenuItem_Click(object sender, EventArgs e)
      {
          using (ColorDialog dlg = new ColorDialog())
          {
              dlg.Color = this.colorBack;
              if (dlg.ShowDialog() == DialogResult.OK)
              {
                  this.colorBack = dlg.Color;
                  panelDraw.Invalidate();
              }
          }
      }

      private void HatchBrushesForm_MouseDown(object sender, MouseEventArgs e)
      {
          
          Console.Out.WriteLine("Mouse Down: {0}", e.Location);
      }

      private void panelDraw_Paint(object sender, PaintEventArgs e)
      {
          Graphics g = e.Graphics;
          string[] hatchNames = Enum.GetNames(typeof(HatchStyle));
          int x = 0;
          int y = 0;
          int width = panelDraw.ClientRectangle.Width / 4;
          int height = panelDraw.ClientRectangle.Height / (hatchNames.Length / 4);
          Brush blackBrush = System.Drawing.Brushes.Black;
          Pen blackPen = Pens.Black;

          Array.Sort(hatchNames);

          foreach (string hatchName in hatchNames)
          {
              HatchStyle style = (HatchStyle)Enum.Parse(typeof(HatchStyle), hatchName);
              using (HatchBrush brush = new HatchBrush(style, colorFore, colorBack))
              {
                  g.FillRectangle(brush, x, y + height / 2, width, height / 2);
                  g.DrawRectangle(blackPen, x, y, width, height);
                  g.DrawString(hatchName, this.Font, blackBrush, x, y);
                  x += width;
                  if (x > panelDraw.ClientRectangle.Width - width)
                  {
                      y += height;
                      x = 0;
                  }
              }
          }
      }

      private void panel1_MouseDown(object sender, MouseEventArgs e)
      {
          Console.Out.WriteLine("Panel Mouse Down: {0}", e.Location);
      }

      private void HatchBrushesForm_Load(object sender, EventArgs e)
      {
          
      }

      private void HatchBrushesForm_Resize(object sender, EventArgs e)
      {
          if (invalidatePanelOnRedrawToolStripMenuItem.Checked)
          {
              panelDraw.Invalidate(true);
          }
      }
  }
}