﻿#region Using directives

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using System.Drawing.Imaging;

#endregion

namespace ImagesSample {
  partial class DrawingToImagesForm : Form {
    public DrawingToImagesForm() {
      InitializeComponent();
    }

    private int offset;

    private void saveButton_Click(object sender, EventArgs e) {
      Rectangle rect = new Rectangle(0, 0, 100, 100);

      // Get current graphics object for display
      using( Graphics displayGraphics = this.CreateGraphics() )

      // Create bitmap to draw into based on existing Graphics object
      using( Image image = new Bitmap(rect.Width, rect.Height, displayGraphics) )

      // Wrap Graphics object around image to draw into
      using (Graphics imageGraphics = Graphics.FromImage(image))
      {
          ImageDraw(imageGraphics, rect);

        // Save created image to a file
        string file = "image.png";
        image.Save(file, ImageFormat.Png);

        MessageBox.Show("Saved to file: " + file);
      }
    }

    private void ImageDraw(Graphics imageGraphics, Rectangle rect) {

        using (Brush brush = new SolidBrush(panelDraw.BackColor))
        {
            imageGraphics.FillRectangle(brush, rect);
        }
        StringFormat format = new StringFormat();
        format.Alignment = StringAlignment.Center;
        format.LineAlignment = StringAlignment.Center;
        using (Brush brush = new SolidBrush(panelDraw.ForeColor))
        {
            imageGraphics.DrawString(toolStripTextBoxMessage.Text, 
                panelDraw.Font, brush, rect, format);
        }

    }

    private void DrawingToImagesForm_Load(object sender, EventArgs e) {
      offset = this.ClientRectangle.Height - this.panelDraw.Height;
    }

    private void DrawingToImagesForm_Layout(object sender, LayoutEventArgs e) {
      this.panelDraw.Height = this.ClientRectangle.Height - offset;
    }

    private void panel1_Paint(object sender, PaintEventArgs e) {
      Graphics g = e.Graphics;
      Rectangle rect = this.panelDraw.ClientRectangle;

      // Create bitmap to draw into based on existing Graphics object
      using( Image image = new Bitmap(rect.Width, rect.Height, g) )
      // Wrap Graphics object around image to draw into
      using( Graphics imageGraphics = Graphics.FromImage(image) ) {
          ImageDraw(imageGraphics, rect);

        // Draw created image to screen
        g.DrawImage(image, rect);
      }
    }

    private void buttonShow_Click(object sender, EventArgs e)
    {
        using (Form form = new Form())
        using (Bitmap bmp = new Bitmap("image.png")) 
        {
            //bmp.RotateFlip(RotateFlipType.RotateNoneFlipXY);
            form.BackgroundImage = bmp;
            form.ShowDialog();
        }
    }

    private void foregroundToolStripMenuItem_Click(object sender, EventArgs e)
    {
        using (ColorDialog dlg = new ColorDialog())
        {
            dlg.Color = panelDraw.ForeColor;
            dlg.ShowDialog();
            panelDraw.ForeColor = dlg.Color;
        }
    }

    private void backgroundToolStripMenuItem_Click(object sender, EventArgs e)
    {
        using (ColorDialog dlg = new ColorDialog())
        {
            dlg.Color = panelDraw.BackColor;
            dlg.ShowDialog();
            panelDraw.BackColor = dlg.Color;
        }
    }

    private void colorToolStripMenuItem_DropDownClosed(object sender, EventArgs e)
    {
        Invalidate(true);
    }
  }
}