﻿#region Using directives

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.Windows.Forms;

#endregion

namespace PathsSolution {
  public partial class MainForm : Form {
    public MainForm() {
      InitializeComponent();
      this.SetStyle(ControlStyles.ResizeRedraw, true);
      this.SetStyle(ControlStyles.OptimizedDoubleBuffer, true);
      this.SetStyle(ControlStyles.AllPaintingInWmPaint, true);
    }

    GraphicsPath GetRoundedRectPath(Rectangle rect, int radius) {
      int diameter = 2 * radius;
      Rectangle arcRect = new Rectangle(rect.Location, new Size(diameter, diameter));
      GraphicsPath path = new GraphicsPath();

      // top left
      path.AddArc(arcRect, 180, 90);

      // top right
      arcRect.X = rect.Right - diameter;
      path.AddArc(arcRect, 270, 90);

      path.StartFigure();

      // bottom right
      arcRect.Y = rect.Bottom - diameter;
      path.AddArc(arcRect, 0, 90);

      // bottom left
      arcRect.X = rect.Left;
      path.AddArc(arcRect, 90, 90);

      path.CloseFigure();
      

      return path;
    }

    GraphicsPath GetClosedBezierPath(Rectangle rect, Point[] points) {
      GraphicsPath path = new GraphicsPath();
      path.AddBeziers(points);
      path.CloseFigure();
      return path;
    }

    GraphicsPath GetDonutPath(Rectangle rect, int holeRadius) {

      GraphicsPath path = new GraphicsPath();
      //      path.FillMode = FillMode.Winding;
      path.AddEllipse(rect);
      Point centerPoint = new Point(rect.Left + rect.Width / 2, rect.Top + rect.Height / 2);
      Rectangle holeRect = new Rectangle(centerPoint.X - holeRadius, centerPoint.Y - holeRadius, holeRadius * 2, holeRadius * 2);
      //  path.StartFigure();
      path.AddEllipse(holeRect);

      // Combining text as a figure
      StringFormat format = new StringFormat();
      format.Alignment = StringAlignment.Center;
      format.LineAlignment = StringAlignment.Center;
      path.AddString("ooohhhh, donuts...", this.Font.FontFamily, (int)this.Font.Style, this.Font.Height, rect, format);

      return path;
    }

    // Need to pass in DPI = 100 for GraphicsUnit == Display
    GraphicsPath GetStringPath(
        string s,
        float dpi,
        RectangleF rect,
        Font font,
        StringFormat format) {
      GraphicsPath path = new GraphicsPath();
      // Convert font size into appropriate coordinates
      float emSize = dpi * font.SizeInPoints / 72;
      path.AddString(s, font.FontFamily, (int)font.Style, emSize, rect, format);
      return path;
    }

      GraphicsPath WindingPath(Rectangle rect, int offset)
      {
          GraphicsPath path = new GraphicsPath();
          path.AddLines(new Point[]{
              new Point(rect.Right - 10, rect.Bottom - 40),
              new Point(rect.Right - 10, rect.Top + 40),
              new Point(rect.Left + 40, rect.Top + 40),
              new Point(rect.Left + 40, rect.Bottom - 10),
              new Point(rect.Left + offset, rect.Top + 10),
              new Point(rect.Left + offset, rect.Top + offset / 2),
              new Point(rect.Left + 10, rect.Bottom - 40)
          });
          path.CloseFigure();
          return path;
      }

      private GraphicsPath CreatePath(Graphics g)
      {
          GraphicsPath path = null;
          int width = panelDraw.ClientRectangle.Width;
          int height = panelDraw.ClientRectangle.Height;
          Rectangle rect = new Rectangle(10, 10, width - 20, height - 20);
           switch (index) {
              case 0:
                  path = GetRoundedRectPath(rect, width / 10);
                  break;
              case 1:
                  path = GetClosedBezierPath(rect, new Point[] { 
                      new Point(25, height - 25), 
                      new Point(width - 25, height - 25), 
                      new Point(25, 25), 
                      new Point(width - 25, 25), });
                  break;
              case 2:
                  path = GetDonutPath(rect, width / 5);
                  break;
              case 3:
                  StringFormat format = new StringFormat();
                  format.Alignment = StringAlignment.Center;
                  format.LineAlignment = StringAlignment.Center;
                  path = GetStringPath("Ain't paths cool?", 100, rect, this.Font, format);
                  break;
              case 4:
                  path = WindingPath(rect, width / 2);
                  break;
              default:
                  path = GetDonutPath(rect, width / 5); 
                  break;
          }
          return path;
      }

    private void MainForm_Paint(object sender, PaintEventArgs e) {
    }
      private int index = 0;
      private void MainForm_Load(object sender, EventArgs e)
      {
          toolStripComboBox1.SelectedIndex = index;
          toolStripComboBoxShape.SelectedIndex = index;
      }

      private void toolStripComboBox1_SelectedIndexChanged(object sender, EventArgs e)
      {
          index = toolStripComboBox1.SelectedIndex;
          panelDraw.Invalidate(true);
      }

      private void panelDraw_Paint(object sender, PaintEventArgs e)
      {
          Graphics g = e.Graphics;

          using (GraphicsPath path = CreatePath(g))
          {
              if (checkBoxWinding.Checked)
              {
                  path.FillMode = FillMode.Winding;
              }
              g.FillPath(Brushes.Yellow, path);
              g.DrawPath(Pens.Black, path);
          }

      }

      private void toolStripComboBox1_Click(object sender, EventArgs e)
      {

      }

      private void toolStripComboBoxShape_SelectedIndexChanged(object sender, EventArgs e)
      {
          index = toolStripComboBoxShape.SelectedIndex;
          panelDraw.Invalidate(true);
      }

      private void checkBoxWinding_CheckedChanged(object sender, EventArgs e)
      {
          panelDraw.Invalidate(true);
      }
  }
}