using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;

namespace ch05
{
    public partial class Ch05MainForm : Form
    {
        private Form mainFormSaved;
        private ApplicationContext ctx;
        public Ch05MainForm()
        {
            ctx = null;
            InitializeComponent();
            panelBezier.Paint += new PaintEventHandler(panel1_Paint);
        }

        public Ch05MainForm(ApplicationContext ctx)
        {
            this.ctx = ctx;
            InitializeComponent();
            panelBezier.Paint += new PaintEventHandler(panel1_Paint);
        }

        void panel1_Paint(object sender, PaintEventArgs e)
        {
            DrawPanel(e.Graphics);
        }

        bool bDrawEllipse = false;
        private void buttonDrawEllipse_Click(object sender, EventArgs e)
        {
            bDrawEllipse ^= true;
            if (bDrawEllipse)
            {
                buttonDrawEllipse.Text = "Hide Ellipse";
            }
            else
            {
                buttonDrawEllipse.Text = "Draw Ellipse";
            }
            if (checkBoxPaint.Checked)
            {
                Invalidate(checkBoxInvalidateTrue.Checked);
            }
            else 
            {
                using (Graphics g = this.CreateGraphics())
                {
                    if (this.bDrawEllipse)
                    {
                        DrawEllipse(g);
                    }
                    else
                    {
                        g.FillEllipse(SystemBrushes.Control, this.ClientRectangle);
                    }
                }
            }
        }

        private void checkBoxPaint_CheckedChanged(object sender, EventArgs e)
        {
            Invalidate(checkBoxInvalidateTrue.Checked);
        }

        private void DrawEllipse(Graphics g)
        {
            g.FillEllipse(Brushes.DarkBlue, this.ClientRectangle);
        }

        private void DrawPanel(Graphics g)
        {
            g.FillRectangle(SystemBrushes.Control, panelBezier.ClientRectangle); 
            g.DrawBezier(Pens.Red, 
                ptList[pos],
                ptList[(pos + 1) % 4],
                ptList[(pos + 2) % 4],
                ptList[(pos + 3) % 4]);
            pos = (pos + 1) % 4;
        }

        Rectangle rectPanel;
        Point[] ptList = new Point[4];
        int pos = 0;
        private void Form1_Load(object sender, EventArgs e)
        {
            if (ctx != null)
            {
                mainFormSaved = ctx.MainForm;
                ctx.MainForm = this;
            }
            rectPanel = panelBezier.ClientRectangle;
            ptList[0] = new Point(rectPanel.Left, rectPanel.Top);
            ptList[1] = new Point(rectPanel.Right, rectPanel.Top);
            ptList[2] = new Point(rectPanel.Left, rectPanel.Bottom);
            ptList[3] = new Point(rectPanel.Right, rectPanel.Bottom);
        }

        private void checkBoxPaint_Paint(object sender, PaintEventArgs e)
        {
            
        }

        private void Form1_Paint(object sender, PaintEventArgs e)
        {
            if (checkBoxPaint.Checked && bDrawEllipse)
            {
                DrawEllipse(e.Graphics);
            }
        }

        private void checkBoxStyle_CheckedChanged(object sender, EventArgs e)
        {
            this.SetStyle(ControlStyles.ResizeRedraw, checkBoxStyle.Checked);
        }

        private void buttonInvalidate_Click(object sender, EventArgs e)
        {
            Invalidate(checkBoxInvalidateTrue.Checked);
            Console.WriteLine("checkBoxInvalidateTrue.Checked: {0}", checkBoxInvalidateTrue.Checked);
        }

        private void checkBoxInvalidateTrue_CheckedChanged(object sender, EventArgs e)
        {

        }

        private void buttonDialog_Click(object sender, EventArgs e)
        {
            new Ch05MainForm().Show();
        }

        private void Ch05MainForm_Resize(object sender, EventArgs e)
        {
            Invalidate(true);
        }

        private void Ch05MainForm_FormClosing(object sender, FormClosingEventArgs e)
        {
            if (ctx != null)
            {
                ctx.MainForm = mainFormSaved;
            }
        }

        bool bDrag = false;
        Size szDown;
        private void panelBezier_MouseDown(object sender, MouseEventArgs e)
        {
            bDrag = true;
            szDown = new Size(e.Location);
        }

        private void panelBezier_MouseMove(object sender, MouseEventArgs e)
        {
            if (bDrag)
            {
                panelBezier.Location = panelBezier.Location - szDown + new Size(e.Location);
                panelBezier.Invalidate();
            }
        }

        private void panelBezier_MouseUp(object sender, MouseEventArgs e)
        {
            panelBezier_MouseMove(sender, e);
            bDrag = false;
        }
    }
}